@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.54 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-history.c,v 1.56.2.1 2005/07/08 21:15:43 chpe Exp $
  */
 
 #include "config.h"
@@ -54,11 +54,11 @@ struct _EphyHistoryPrivate
 	EphyNode *last_page;
 	GHashTable *hosts_hash;
 	GHashTable *pages_hash;
-	int autosave_timeout;
+	guint autosave_timeout;
 	guint update_hosts_idle;
+	guint disable_history_notifier_id;
 	gboolean dirty;
 	gboolean enabled;
-	guint disable_history_notifier_id;
 };
 
 enum
@@ -115,7 +115,7 @@ static void
 ephy_history_set_enabled (EphyHistory *history,
 			  gboolean enabled)
 {
-	LOG ("ephy_history_set_enabled %d", enabled)
+	LOG ("ephy_history_set_enabled %d", enabled);
 
 	history->priv->enabled = enabled;
 
@@ -267,7 +267,7 @@ ephy_history_save (EphyHistory *eb)
 		return;
 	}
 
-	LOG ("Saving history db")
+	LOG ("Saving history db");
 
 	ret = ephy_node_db_write_to_xml_safe
 		(eb->priv->db, eb->priv->xml_file,
@@ -616,7 +616,7 @@ ephy_history_finalize (GObject *object)
 }
 
 EphyHistory *
-ephy_history_new ()
+ephy_history_new (void)
 {
 	return EPHY_HISTORY (g_object_new (EPHY_TYPE_HISTORY, NULL));
 }
@@ -629,7 +629,7 @@ ephy_history_host_visited (EphyHistory *eh,
 	GValue value = { 0, };
 	int visits;
 
-	LOG ("Host visited")
+	LOG ("Host visited");
 
 	visits = ephy_node_get_property_int
 		(host, EPHY_NODE_PAGE_PROP_VISITS);
@@ -918,7 +918,7 @@ ephy_history_set_page_title (EphyHistory *gh,
 	EphyNode *node;
 	GValue value = { 0, };
 
-	LOG ("Set page title")
+	LOG ("Set page title");
 
 	if (title == NULL || title[0] == '\0') return;
 
@@ -959,7 +959,7 @@ ephy_history_set_icon (EphyHistory *gh,
 {
 	EphyNode *host;
 
-	LOG ("Set host icon")
+	LOG ("Set host icon");
 
 	host = g_hash_table_lookup (gh->priv->hosts_hash, url);
 	if (host)
@@ -979,7 +979,7 @@ ephy_history_clear (EphyHistory *gh)
 {
 	EphyNode *node;
 
-	LOG ("clearing history")
+	LOG ("clearing history");
 
 	ephy_node_db_set_immutable (gh->priv->db, FALSE);
 
