@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.76.2.7 2005/06/05 09:36:06 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.76.2.9 2005/08/13 12:58:33 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -482,6 +482,9 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 					 getter_AddRefs(mWebBrowser));
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
+	mWebBrowserFocus = do_QueryInterface (mWebBrowser);
+	NS_ENSURE_TRUE (mWebBrowserFocus, NS_ERROR_FAILURE);
+
 	mWebBrowser->GetContentDOMWindow (getter_AddRefs (mDOMWindow));
 	NS_ENSURE_TRUE (mDOMWindow, NS_ERROR_FAILURE);
 
@@ -745,46 +748,6 @@ nsresult EphyBrowser::GoToHistoryIndex (PRInt16 index)
 	return ContentNav->GotoIndex (index);
 }
 
-#ifdef GTKMOZEMBED_BROKEN_RELOAD
-/* Workaround for broken reload with frames, see mozilla bug
- * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
- */
-nsresult EphyBrowser::Reload (ReloadType flags)
-{
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsISHistory> sessionHistory;
-	GetSHistory (getter_AddRefs (sessionHistory));
-
-	nsCOMPtr<nsIWebNavigation> webNavigation;
-	webNavigation = do_QueryInterface (sessionHistory);
-
-	if (!webNavigation)
-	{
-		webNavigation = do_QueryInterface (mWebBrowser);
-	}
-	NS_ENSURE_TRUE (webNavigation, NS_ERROR_FAILURE);
-
-	PRUint32 reloadFlags;
-	switch (flags)
-	{
-		case RELOAD_FORCE:
-			reloadFlags = nsIWebNavigation::LOAD_FLAGS_BYPASS_CACHE | 
-				      nsIWebNavigation::LOAD_FLAGS_BYPASS_PROXY;
-			break;
-		case RELOAD_ENCODING_CHANGE:
-			reloadFlags = nsIWebNavigation::LOAD_FLAGS_CHARSET_CHANGE;
-			break;
-		case RELOAD_NORMAL:
-		default:
-			reloadFlags = 0;
-			break;
-	}
-
-	return webNavigation->Reload (reloadFlags);
-}
-#endif
-
 nsresult EphyBrowser::SetZoom (float aZoom)
 {
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
@@ -843,13 +806,9 @@ nsresult EphyBrowser::GetTargetDocument (nsIDOMDocument **aDOMDocument)
 	}
 
 	/* Use the focused document */
-	nsCOMPtr<nsIWebBrowserFocus> webBrowserFocus;
-	webBrowserFocus = do_QueryInterface (mWebBrowser);
-	NS_ENSURE_TRUE (webBrowserFocus, NS_ERROR_FAILURE);
-
 	nsresult rv;
 	nsCOMPtr<nsIDOMWindow> DOMWindow;
-	rv = webBrowserFocus->GetFocusedWindow (getter_AddRefs(DOMWindow));
+	rv = mWebBrowserFocus->GetFocusedWindow (getter_AddRefs(DOMWindow));
 	if (NS_SUCCEEDED (rv) && DOMWindow)
 	{
 		return DOMWindow->GetDocument (aDOMDocument);
@@ -1335,3 +1294,21 @@ EphyBrowser::GetDocumentType ()
 
   return type;
 }
+
+#ifdef GTKMOZEMBED_BROKEN_FOCUS
+nsresult
+EphyBrowser::FocusActivate ()
+{
+	NS_ENSURE_STATE (mWebBrowserFocus);
+
+	return mWebBrowserFocus->Activate();
+}
+
+nsresult
+EphyBrowser::FocusDeactivate ()
+{
+	NS_ENSURE_STATE (mWebBrowserFocus);
+
+	return mWebBrowserFocus->Deactivate();
+}
+#endif /* GTKMOZEMBED_BROKEN_FOCUS */
