@@ -36,10 +36,11 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.h,v 1.11 2004/05/08 13:34:55 chpe Exp $
+ * $Id: EphyHeaderSniffer.h,v 1.14.2.1 2005/04/07 11:46:32 chpe Exp $
  */
 
 #include "mozilla-embed-persist.h"
+#include "ephy-embed-single.h"
 
 #include <nsIWebProgressListener.h>
 #include <nsIWebBrowserPersist.h>
@@ -49,18 +50,17 @@
 #include <nsIDOMDocument.h>
 #include <nsIAuthPrompt.h>
 #include <nsIPromptService.h>
-
-#ifdef ALLOW_PRIVATE_STRINGS
-#include <nsString.h>
-#endif
+#undef MOZILLA_INTERNAL_API
+#include <nsEmbedString.h>
+#define MOZILLA_INTERNAL_API 1
 
 class EphyHeaderSniffer : public nsIWebProgressListener,
 			  public nsIAuthPrompt
 {
 public:
 	EphyHeaderSniffer (nsIWebBrowserPersist* aPersist, MozillaEmbedPersist *aEmbedPersist,
-		           nsIFile* aFile, nsIURI* aURL,
-                           nsIDOMDocument* aDocument, nsIInputStream* aPostData);
+		           nsIFile* aFile, nsIURI* aURL, nsIDOMDocument* aDocument,
+			   nsIInputStream* aPostData, EphyEmbedSingle *single);
 	virtual ~EphyHeaderSniffer ();
 
 	NS_DECL_ISUPPORTS
@@ -76,13 +76,14 @@ protected:
 private:
 	nsIWebBrowserPersist*      mPersist; /* Weak. It owns us as a listener. */
 	MozillaEmbedPersist       *mEmbedPersist;
+	EphyEmbedSingle		  *mSingle;
 	nsCOMPtr<nsIFile>          mTmpFile;
 	nsCOMPtr<nsIURI>           mURL;
 	nsCOMPtr<nsIURI>           mOriginalURI;
 	nsCOMPtr<nsIDOMDocument>   mDocument;
 	nsCOMPtr<nsIInputStream>   mPostData;
-	nsCString                  mContentType;
-	nsCString                  mContentDisposition;
+	nsEmbedCString             mContentType;
+	nsEmbedCString             mContentDisposition;
 	nsCOMPtr<nsIAuthPrompt>    mAuthPrompt;
 };
 
