@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.27 2005/01/15 20:08:06 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.27.2.2 2005/05/30 17:01:08 chpe Exp $
  */
 
 /*
@@ -45,9 +45,9 @@
 #include <nsICRLInfo.h>
 #include <nsISimpleEnumerator.h>
 #include <nsIArray.h>
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtkdialog.h>
@@ -616,7 +616,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_software)))
 		{
-			*_trust |= nsIX509CertDB::TRUSTED_SSL;
+			*_trust |= nsIX509CertDB::TRUSTED_OBJSIGN;
 		}
 		*_retval = PR_TRUE;
 	}
