@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-string.h,v 1.8 2003/12/13 22:29:00 chpe Exp $
+ *  $Id: ephy-string.h,v 1.12 2004/12/13 18:58:58 chpe Exp $
  */
 
 #ifndef EPHY_STRING_H
@@ -30,13 +30,6 @@ gboolean	 ephy_string_to_int			(const char *string,
 
 char		*ephy_string_blank_chr			(char *source);
 
-char		*ephy_string_shorten			(const char *str,
-							 int target_length);
-
-char		*ephy_string_elide_underscores		(const char *original);
-
-char            *ephy_string_double_underscores         (const char *string);
-
 G_END_DECLS
 
 #endif
