@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.100 2005/01/20 19:04:31 jframeau Exp $
+ *  $Id: ephy-bookmarks.c,v 1.103.2.1 2005/07/24 12:20:02 chpe Exp $
  */
 
 #include "config.h"
@@ -219,7 +219,7 @@ ephy_bookmarks_get_toolbars_model (EphyBookmarks *eb)
 {
 	g_return_val_if_fail (EPHY_IS_BOOKMARKS (eb), NULL);
 
-	LOG ("ephy_bookmarks_get_toolbars_model")
+	LOG ("ephy_bookmarks_get_toolbars_model");
 
 	if (eb->priv->toolbars_model == NULL)
 	{
@@ -313,7 +313,7 @@ static void
 ephy_bookmarks_save (EphyBookmarks *eb)
 {
 
-	LOG ("Saving bookmarks")
+	LOG ("Saving bookmarks");
 
 	ephy_node_db_write_to_xml_safe
 		(eb->priv->db,
@@ -540,7 +540,7 @@ redirect_cb (EphyHistory *history,
 				/* translators: the %s is the title of the bookmark */
 				_("Update bookmark \"%s\"?"),
 				title);
-	gtk_message_dialog_format_secondary_markup
+	gtk_message_dialog_format_secondary_text
 		(GTK_MESSAGE_DIALOG (dialog),
 		/* translators: the %s is a URL */
 		_("The bookmarked page has moved to \"%s\"."),
@@ -564,6 +564,9 @@ redirect_cb (EphyHistory *history,
 					 (EphyNodeCallback) update_bookmark_destroy_cb,
 					 G_OBJECT (dialog));
 
+	/* this dialogue is unexpected */
+	gtk_window_set_focus_on_map (GTK_WINDOW (dialog), FALSE);
+
 	gtk_window_present (GTK_WINDOW (dialog));
 }
 
@@ -914,7 +917,7 @@ ephy_bookmarks_finalize (GObject *object)
 	ephy_bookmarks_save (eb);
 
 	/* have to do this before unreffing the nodes */
-        LOG ("Unref bookmarks toolbars model")
+        LOG ("Unref bookmarks toolbars model");
         if (eb->priv->toolbars_model != NULL)
         {
                 g_object_unref (eb->priv->toolbars_model);
@@ -930,13 +933,13 @@ ephy_bookmarks_finalize (GObject *object)
 	g_free (eb->priv->xml_file);
 	g_free (eb->priv->rdf_file);
 
-	LOG ("Bookmarks finalized")
+	LOG ("Bookmarks finalized");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 EphyBookmarks *
-ephy_bookmarks_new ()
+ephy_bookmarks_new (void)
 {
 	EphyBookmarks *eb;
 
@@ -1375,7 +1378,7 @@ ephy_bookmarks_find_keyword (EphyBookmarks *eb,
 
 	if (g_utf8_strlen (name, -1) == 0)
 	{
-		LOG ("Empty name, no keyword matches.")
+		LOG ("Empty name, no keyword matches.");
 		return NULL;
 	}
 
@@ -1435,7 +1438,7 @@ ephy_bookmarks_set_keyword (EphyBookmarks *eb,
 
 	if (ephy_node_has_child (eb->priv->notcategorized, bookmark))
 	{
-		LOG ("Remove from categorized bookmarks")
+		LOG ("Remove from categorized bookmarks");
 		ephy_node_remove_child
 			(eb->priv->notcategorized, bookmark);
 	}
@@ -1457,7 +1460,7 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 	if (!bookmark_is_categorized (eb, bookmark) &&
 	    !ephy_node_has_child (eb->priv->notcategorized, bookmark))
 	{
-		LOG ("Add to not categorized bookmarks")
+		LOG ("Add to not categorized bookmarks");
 		ephy_node_add_child
 			(eb->priv->notcategorized, bookmark);
 	}
